@@ -179,7 +179,7 @@ sub find_uid
         my $auth_id = Exim::expand_string('$authenticated_id');
         my $work_path = $ENV{'PWD'};
 
-	if ($username eq "apache" || $username eq "nobody")
+	if ($username eq "apache" || $username eq "nobody" || $username eq "webapps")
 	{
 		$uid = find_uid_apache($work_path);
 		if ($uid != -1) { return $uid; }
